#!C:\ci\gdal-split_1544666609991\_h_env\python.exe
# EASY-INSTALL-SCRIPT: 'GDAL==2.3.2','gdal2xyz.py'
__requires__ = 'GDAL==2.3.2'
__import__('pkg_resources').run_script('GDAL==2.3.2', 'gdal2xyz.py')
